@@ -25,7 +25,7 @@
 using namespace wreport;
 
 // Read all BUFR messages from a file
-void read_bufr(const Options& opts, const char* fname, BulletinHandler& handler)
+void read_bufr(const Options& opts, const char* fname, BulletinHandler& handler, bool header_only=false)
 {
     // Open the input file
     FILE* in = fopen(fname, "rb");
@@ -51,9 +51,14 @@ void read_bufr(const Options& opts, const char* fname, BulletinHandler& handler)
         // error messages.
         while (BufrBulletin::read(in, raw_data, fname, &offset))
         {
-            // Decode the raw data. fname and offset are optional and we pass
-            // them just to have nicer error messages
-            bulletin->decode(raw_data, fname, offset);
+            if (header_only)
+                // Decode the raw data. fname and offset are optional and we pass
+                // them just to have nicer error messages
+                bulletin->decode_header(raw_data, fname, offset);
+            else
+                // Decode the raw data. fname and offset are optional and we pass
+                // them just to have nicer error messages
+                bulletin->decode(raw_data, fname, offset);
 
             // Do something with the decoded information
             handler.handle(*bulletin);
@@ -75,7 +80,7 @@ void read_bufr(const Options& opts, const char* fname, BulletinHandler& handler)
  *  - it uses a CrexBulletin instead of a BufrBulletin
  *  - it uses CrexBulletin::read instead of BufrBulletin::read
  */
-void read_crex(const Options& opts, const char* fname, BulletinHandler& handler)
+void read_crex(const Options& opts, const char* fname, BulletinHandler& handler, bool header_only=false)
 {
     // Open the input file
     FILE* in = fopen(fname, "rt");
